#!/bin/bash

osdir=`dirname $0`

do_plain=0
do_prop=0
do_sp=0
do_qp=0
do_time=0
do_metrictime=0
extraopt=""

while getopts pPsqtmcx:X: c
do
    case $c in
    p) do_plain=1;;
    P) do_prop=1;;
    s) do_sp=1;;
    q) do_qp=1;;
    t) do_time=1;;
    m) do_metrictime=1;;
    c) extraopt="${extraopt} --cut";;
    x) extraopt="${extraopt} -${OPTARG}";;
    X) extraopt="${extraopt} --${OPTARG}";;
    \?) echo "generate-ipc-instances [-pPsqtm]"
        echo "-p: plain version (objective: min \#actions)"
        echo "-P: propositional version (objective: min parallel length)"
        echo "-s: SP version (objective: metric over preferences)"
        echo "-q: QP version (objective: metric over preferences)"
        echo "-t: Time version (objective: makespan)"
        echo "-m: MetricTime version (objective: metric comb. fluents and makespan)"
        exit 1;;
    esac
done

if [[ $do_plain -gt 0 ]]; then
    echo "generating plain version..."
    $osdir/convertstacks3 ${extraopt} --ipc 01 --skip 3 -n 5 $osdir/misc/small.txt
    $osdir/convertstacks3 ${extraopt} --ipc 06 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --ipc 07 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --ipc 08 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 09 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 10 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --ipc 11 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --ipc 12 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --ipc 13 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --ipc 14 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --ipc 15 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --ipc 16 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --ipc 17 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 18 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 19 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 20 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --ipc 21 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --ipc 22 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --ipc 23 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --ipc 24 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --ipc 25 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --ipc 26 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 27 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --ipc 28 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp100by100.txt
    $osdir/convertstacks3 ${extraopt} --ipc 29 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp100by100.txt
    $osdir/convertstacks3 ${extraopt} --ipc 30 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
fi

if [[ $do_prop -gt 0 ]]; then
    echo "generating Propositional version..."
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 01 --skip 3 -n 5 $osdir/misc/small.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 06 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 07 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 08 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 09 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 10 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 11 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 12 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 13 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 14 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 15 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 16 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 17 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 18 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 19 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 20 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 21 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 22 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 23 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 24 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 25 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 26 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 27 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 28 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp100by100.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 29 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp100by100.txt
    $osdir/convertstacks3 ${extraopt} --sequenced --ipc 30 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
fi

if [[ $do_sp -gt 0 ]]; then
    echo "generating SP version..."
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 4 --ipc 01 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 5 --ipc 02 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 6 --ipc 03 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 6 --ipc 04 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 8 --ipc 05 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 8 --ipc 06 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 11 --ipc 07 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 15 --ipc 08 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 14 --ipc 09 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 13 --ipc 10 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 12 --ipc 11 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 11 --ipc 12 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 9 --ipc 13 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 7 --ipc 14 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 11 --ipc 15 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 11 --ipc 16 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 17 --ipc 17 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --fixed --bounded 21 --ipc 18 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 37 --ipc 19 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --soft --fixed --bounded 27 --ipc 20 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
fi

if [[ $do_qp -gt 0 ]]; then
    echo "generating QP version..."
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 14 --ipc 01 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 11.6 --ipc 02 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 12.8 --skip 2 -n 1 --ipc 03 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 14.2 --skip 3 -n 1 --ipc 04 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 15.5 --ipc 05 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 15.5 --ipc 06 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 25 --ipc 07 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 38.7 --ipc 08 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 41.3 --ipc 09 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 8.5 --ipc 10 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 9.2 --ipc 11 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 12.75 --ipc 12 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 22.3 --ipc 13 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 7.2 --ipc 14 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 17.5 --ipc 15 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 17.5 --ipc 16 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 25 --ipc 17 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --exponential --preferences --weight 42.2 --ipc 18 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 39.5 --ipc 19 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --soft --preferences --weight 44.9 --ipc 20 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
fi

if [[ $do_time -gt 0 ]]; then
    echo "generating Time version..."
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 8 --ipc 01 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 9 --ipc 02 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 13 --ipc 03 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 13 --ipc 04 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 05 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 06 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 07 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 19 --ipc 08 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 09 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 10 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 11 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 12 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 18 --ipc 13 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 23 --ipc 14 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 28 --ipc 15 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 28 --ipc 16 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 28 --ipc 17 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 28 --ipc 18 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 48 --ipc 19 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --time --fixed --bounded 48 --ipc 20 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
fi

if [[ $do_metrictime -gt 0 ]]; then
    echo "generating MetricTime version..."
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   41.0 --ipc 01 --skip 10 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   32.0 --ipc 02 --skip 17 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_10_10.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   55.5 --ipc 03 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   66.5 --ipc 04 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/nwrsSmaller4.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   52.0 --ipc 05 --skip 11 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   27.0 --ipc 06 --skip 13 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   59.0 --ipc 07 --skip 20 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight  100.0 --ipc 08 --skip 34 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   54.5 --ipc 09 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_20_20.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   71.5 --ipc 10 --skip 3 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   73.0 --ipc 11 --skip 23 -n 1 $osdir/ChallengeInstances2005/Shaw/ShawInstances.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   88.0 --ipc 12 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   35.3 --ipc 13 --skip 2 -n 1 $osdir/ChallengeInstances2005/Wilson/nrwsLarger4.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   40.5 --ipc 14 -n 1 $osdir/ChallengeInstances2005/Wilson/sp4.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   23.5 --ipc 15 --skip 16 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   34.5 --ipc 16 --skip 19 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight   78.0 --ipc 17 --skip 25 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight  100.0 --ipc 18 --skip 36 -n 1 $osdir/ChallengeInstances2005/Harvey/wbop_30_30.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight  120.5 --ipc 19 --skip 1 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
    $osdir/convertstacks3 ${extraopt} --time --numeric --weight  144.5 --ipc 20 --skip 3 -n 1 $osdir/ChallengeInstances2005/Wilson/gp50by50.txt
fi
